@@ -54,10 +54,10 @@ class MarkupTestCase(unittest.TestCase):
         self.assertEqual(Markup('<em>%(foo)s</em>') % {
             'foo': '<foo>',
         }, Markup(u'<em>&lt;foo&gt;</em>'))
-        self.assertEqual(unicode(Markup('<em>%(foo)s:%(bar)s</em>') % {
+        self.assertEqual(Markup('<em>%(foo)s:%(bar)s</em>') % {
             'foo': '<foo>',
             'bar': '<bar>',
-        }), unicode(Markup(u'<em>&lt;foo&gt;:&lt;bar&gt;</em>')))
+        }, Markup(u'<em>&lt;foo&gt;:&lt;bar&gt;</em>'))
 
     def test_escaping(self):
         # escaping and unescaping
@@ -65,6 +65,15 @@ class MarkupTestCase(unittest.TestCase):
         assert Markup("<em>Foo &amp; Bar</em>").striptags() == "Foo & Bar"
         assert Markup("&lt;test&gt;").unescape() == "<test>"
 
+    def test_formatting(self):
+        for actual, expected in (
+            (Markup('%i') % 3.14, '3'),
+            (Markup('%.2f') % 3.14159, '3.14'),
+            (Markup('%s %s %s') % ('<', 123, '>'), '&lt; 123 &gt;'),
+            (Markup('<em>{awesome}</em>').format(awesome='<awesome>'),
+             '<em>&lt;awesome&gt;</em>')):
+            assert actual == expected, "%r should be %r!" % (actual, expected)
+
     def test_all_set(self):
         import markupsafe as markup
         for item in markup.__all__:
@@ -75,6 +84,23 @@ class MarkupTestCase(unittest.TestCase):
         assert escape(None) == Markup(None)
         assert escape_silent('<foo>') == Markup(u'&lt;foo&gt;')
 
+    def test_splitting(self):
+        self.assertEqual(Markup('a b').split(), [
+            Markup('a'),
+            Markup('b')
+        ])
+        self.assertEqual(Markup('a b').rsplit(), [
+            Markup('a'),
+            Markup('b')
+        ])
+        self.assertEqual(Markup('a\nb').splitlines(), [
+            Markup('a'),
+            Markup('b')
+        ])
+
+    def test_mul(self):
+        self.assertEqual(Markup('a') * 3, Markup('aaa'))
+
 
 class MarkupLeakTestCase(unittest.TestCase):
 
